@@ -600,22 +600,22 @@ class qeAsyncStratProcess:
                 
                     if self.recmode and not strat.posLoaded:
                         strat.posLoaded = True
-                        pos,instPnl = readStratPosition(strat.name, strat.context.tradingday)
+                        pos,instPnl = readStratPosition_wrap(strat.name, strat.context.tradingday)
                         if pos == {} and instPnl == {}:
                             prev_date = self.getPreviousTradingDay() 
-                            strat.context.position, tmp = readStratPosition(strat.name, prev_date.strftime('%Y%m%d'))
+                            strat.context.position, tmp = readStratPosition_wrap(strat.name, prev_date.strftime('%Y%m%d'))
                             ## Can not load closepnl from previous day
                             strat.context.instClosePnl = {}
                         else:
                             strat.context.position = pos
                             strat.context.instClosePnl = instPnl
                         simuaccount.updateStratPostion(strat.context.position)
-                        strat.context.prodMaxMarg,strat.context.prodTurnover = readStratStat(strat.name,strat.context.tradingday)
+                        strat.context.prodMaxMarg,strat.context.prodTurnover = readStratStat_wrap(strat.name,strat.context.tradingday)
                         ## write back to database
                         strat.context.clearExpirePosition()
-                        writeStratPosition(strat.name, strat.context.tradingday,strat.context.position,strat.context.instClosePnl)
-                        writeContractTable(strat.name, strat.context.tradingday,strat.context.position)
-                        writeStratStat(strat.name,strat.context.tradingday, strat.context.prodMaxMarg, strat.context.prodTurnover)
+                        writeStratPosition_wrap(strat.name, strat.context.tradingday,strat.context.position,strat.context.instClosePnl)
+                        writeContractTable_wrap(strat.name, strat.context.tradingday,strat.context.position)
+                        writeStratStat_wrap(strat.name,strat.context.tradingday, strat.context.prodMaxMarg, strat.context.prodTurnover)
                         strat.context.instsett = qeInstSett()        
                     
                     strat.context.current[tempinstid] = d['data']['current']
@@ -681,9 +681,9 @@ class qeAsyncStratProcess:
                 context = strat.context
                 lastday = context.lastday.replace('-','')
                 strat.context.clearExpirePosition()
-                writeStratPosition(strat.name, lastday,context.position,context.instClosePnl)
-                writeContractTable(strat.name, lastday,context.position)
-                writeStratStat(strat.name,lastday, context.prodMaxMarg, context.prodTurnover)
+                writeStratPosition_wrap(strat.name, lastday,context.position,context.instClosePnl)
+                writeContractTable_wrap(strat.name, lastday,context.position)
+                writeStratStat_wrap(strat.name,lastday, context.prodMaxMarg, context.prodTurnover)
         self.dataslide = {}
         self.presett = {}
            
@@ -719,11 +719,11 @@ class qeAsyncStratProcess:
                     context.simuTrade(trade)
                     context.updateData() 
                     if self.recmode:
-                        writeStratPosition(strat.name, context.tradingday,context.position,context.instClosePnl)
-                        writeContractTable(strat.name, context.tradingday,context.position)
-                        writeStratStat(strat.name,context.tradingday, context.prodMaxMarg, context.prodTurnover)
-                        writeStratTrade(strat.name,context.tradingday, trade)
-                        writeContract_messages(strat.name,context.tradingday, trade)
+                        writeStratPosition_wrap(strat.name, context.tradingday,context.position,context.instClosePnl)
+                        writeContractTable_wrap(strat.name, context.tradingday,context.position)
+                        writeStratStat_wrap(strat.name,context.tradingday, context.prodMaxMarg, context.prodTurnover)
+                        writeStratTrade_wrap(strat.name,context.tradingday, trade)
+                        writeContract_messages_wrap(strat.name,context.tradingday, trade)
         except Exception as e:
             logger.error(f"handletrade error {e}",exc_info=True )
     
