@@ -210,8 +210,8 @@ class qeStratProcess:
 #                             print('stratprocess market data')
                             savedInsts = strat.instid.copy();
                             self.updateData(d,context)
-                            self.autoOrders(d, context)
-                            self.algoTrade(d,context)
+                            #self.autoOrders(d, context)
+                            #self.algoTrade(d,context)
                                 #if context.runmode == 'simu':
                                 #    context.account.noticeCrossDay(self.name)
                             #self.refresh(d,context) 
@@ -280,8 +280,8 @@ class qeStratProcess:
                                     #context.instsett = qeInstSett()
                                     for inst in savedInsts:
                                         tmpd ={'instid':inst}
-                                        self.autoOrders(tmpd, context)
-                                        self.algoTrade(tmpd,context)
+                                        #self.autoOrders(tmpd, context)
+                                        #self.algoTrade(tmpd,context)
                                     renew = False
                                     if self.wait_all and self.info_time != g_userinfo.info_time_all:
                                         self.info_time = g_userinfo.info_time_all
@@ -375,204 +375,6 @@ class qeStratProcess:
             print('liquidate strategy '+str(self.name))
     
             
-    def algoTrade(self,d,context):
-        try:
-            curtime = datetime.now()
-            for aid in context.algoorders:
-                order = context.algoorders[aid]
-                if order['leftvol'] > 0:
-                    if (curtime - order['starttime']).seconds >=  order['freq']:
-                        leftvol = 0
-                        orderids = order['orderids']
-                        tvol = 0
-                        cvol = 0
-                        fvol = 0
-                        bError = False
-                        for oid in orderids:
-                            cvol += context.orders[oid]['cancelvol']
-                            fvol += context.orders[oid]['tradevol']
-                            tvol += context.orders[oid]['volume']
-                            if context.orders[oid]['errorid'] != 0:
-                                bError = True
-                        leftvol = order['volume'] - tvol
-                        if bError or cvol > 0:
-                            leftvol = 0
-                            basevol = 0 
-                        elif order['ordertype'] == 'market':
-                            if curtime >= order['endtime'] or abs(order['endtime'] - curtime).seconds < 1:
-                                basevol = leftvol
-                            else:
-                                lefttime = (order['endtime'] - curtime).seconds
-                                basevol = order['freq'] * leftvol / lefttime
-                                random_factor = order['factor']
-                                basevol = round(basevol * (1 + random.randint(-random_factor, random_factor)/100))
-                                basevol = min(basevol, leftvol)
-                        else:
-                            if fvol==tvol and curtime <= order['endtime'] - timedelta(seconds=1):
-                                basevol = order['basevol']
-                            else:
-                                basevol = 0
-                            if  order['limitcount'] > 0:
-                                context.algoorders[aid]['limitcount']-= 1    
-                                if context.algoorders[aid]['limitcount'] == 0:
-                                    basevol = min(basevol, leftvol)
-                            else:
-                                basevol = 0
-                                leftvol = 0
-                                for oid in order['orderids']:
-                                    if context.orders[oid]['leftvol'] > 0:
-                                        cancel_order(context, oid)
-                        if basevol > 0:    
-                            ret, oids = make_order(context, order['instid'], order['direction'], order['price'], basevol,order['ordertype'], order['action'],timecond=order['timecond'],accid=order['accid'])  
-                            if ret == 0:
-                                context.algoorders[aid]['orderids'] += oids
-                        context.algoorders[aid]['starttime'] = curtime
-                        context.algoorders[aid]['leftvol'] = leftvol
-    
-        except Exception as e:
-            logger.error(f"qestratprocess algoTrade error {e}",exc_info=True )  
-
-    def autoOrders(self, d, context):
-        try:
-            inst = d['instid']
-            remakelist = []
-            
-            for oid in context.orders:
-                corder = context.orders[oid]
-                    #### deal with autocancel
-                logged = False    
-                #if 'I2301' in corder['instid']:
-                    #print('deal with i2301')
-                #    logged = True
-                current = context.getCurrent(corder['instid'])
-                if 'autocancel' in corder:
-                    statusloc = 3
-                    if corder['leftvol'] > 0 and corder['autocancel'][:2] != [0 , 0] and corder['autocancel'][statusloc] == 'wait':
-                        [canceltime, canceltick, starttime,status] =  corder['autocancel']
-                        if canceltime > 0 and (datetime.now() - starttime).seconds >= canceltime: 
-                              context.orders[oid]['autocancel'][statusloc] = 'cancel'
-                              cancel_order(context, corder['orderid'])
-                              
-                              
-                        if canceltick > 0:
-                              
-                              openprice = corder['price']
-                              ticksize = None
-                              if instSetts.get(corder['instid']):
-                                  ticksize =  instSetts[corder['instid']].get('ticksize')
-                              if current >0  and not ticksize is None:
-                                  if corder['direction'] > 0 and current - openprice >= canceltick * ticksize:
-                                       cancel_order(context, corder['orderid'])
-                                       context.orders[oid]['autocancel'][statusloc] = 'cancel'
-                                  if corder['direction'] < 0 and openprice - current >= canceltick * ticksize:
-                                       cancel_order(context, corder['orderid'])
-                                       context.orders[oid]['autocancel'][statusloc] = 'cancel'
-                                  
-                ######## deal with auto remake order
-                remake = False
-                statusloc = 5
-                #if corder['instid']==inst and 
-                if 'autoremake' in corder and len(corder['autoremake']) == statusloc+1 \
-                    and corder['autoremake'][0] > 0 and corder['autoremake'][statusloc]!='finished':
-                    [mode, rmtime, rmticks, rmcount, rmstart, status] = corder['autoremake']
-                    #print('automake', (context.curtime - rmstart).seconds, status)
-                    if corder['errorid'] != 0:
-                        corder['autoremake'][statusloc] = 'finished'
-                        if logged:
-                            print('remake finished')
-                        continue
-                    ticksize = None
-                    if instSetts.get(corder['instid']):
-                        ticksize =  instSetts[corder['instid']].get('ticksize')
-                    if ticksize is None:
-                        if logged:
-                            print('ticksize finished')
-                        continue
-                    price = context.getDataSlide(corder['instid'], 'a1_p') if corder['direction'] > 0 else context.getDataSlide(corder['instid'], 'b1_p')
-                    if price == 0 and  current > 0:
-                        price = current
-                    if price == 0:
-                        if logged:
-                            print('price finished')
-                        continue
-                    
-                    timecond = 'GFD'
-                    if mode == 1: # FAK track mode
-                        if corder['leftvol'] == 0:
-                            if corder['cancelvol'] > 0 and rmcount > 0 and status =='wait':      
-                                autorm = [mode, 0,0, rmcount-1]
-                                timecond = 'FAK'
-                                remake = True
-                            else:
-                                context.orders[oid]['autoremake'][statusloc] ='finished'
-                                if logged:
-                                    print('fak finished')
-                                continue
-                            
-                    elif mode == 2: # GFD track timeout or ticks
-                        if corder['leftvol'] > 0: # and rmcount > 0:
-                            if rmtime > 0 and (datetime.now()- rmstart).seconds >= rmtime and status=='wait':
-                                context.orders[oid]['autoremake'][statusloc] = 'cancel'
-                                cancel_order(context, corder['orderid'])
-                                print('cancel order by time',rmtime,'left',rmcount-1)
-                            elif rmticks > 0 and abs(price - corder['price'])/ticksize >= rmticks and status=='wait':
-                                context.orders[oid]['autoremake'][statusloc] = 'cancel'
-                                cancel_order(context, corder['orderid'])
-                                print('cancel order by ticks',rmticks,'left',rmcount-1)
-                        
-                        elif corder['leftvol'] == 0 and status =='cancel': 
-                            if rmtime > 0  :      
-                                rmcount -= 1
-                                autorm = [mode, rmtime, rmticks, max(0,rmcount)]
-                                remake = (rmcount > 0)
-                                #print('rmcount', rmcount, remake)
-                            elif rmticks > 0 :      
-                                rmcount -= 1
-                                autorm = [mode, rmtime, rmticks, max(0,rmcount)]
-                                remake = (rmcount > 0)
-                        elif corder['leftvol'] == 0:
-                                context.orders[oid]['autoremake'][statusloc] ='finished'
-                                if logged:
-                                    print('gfd finished')
-                                continue
-                                
-                                
-                    if logged:
-                            print('remake:',remake)
-    
-                    if remake:
-                        remakelist.append([oid,ticksize,price,autorm,timecond])
-            if len(remakelist) > 0:
-                for rem in remakelist:
-                        [oid,ticksize,price,autorm,timecond] = rem
-                        corder = context.orders[oid]
-                        if 'autocancel' in corder and  corder['autocancel'][:2] != [0 , 0]:
-                            [canceltime, canceltick, starttime,status] =  corder['autocancel']
-                            if (datetime.now() - starttime).seconds < canceltime:
-                                lefttime = canceltime - (datetime.now() - starttime).seconds
-                                lefttick = canceltick - int(abs(price - corder['price'])/ticksize)
-                                autocancel = [lefttime, lefttick]
-                            else:
-                                autocancel = [0,0]
-                            #print('make order autocancel:',lefttime, lefttick)
-                        else:
-                            autocancel =[0,0]
-                        
-                        father = oid if context.orders[oid]['father'] == 0 else context.orders[oid]['father']
-                        
-                        ret,orderids = make_order(context, corder['instid'], corder['direction'], price, corder['cancelvol'],corder['ordertype'],\
-                                   corder['action'],corder['closetype'], timecond=timecond, autoremake=autorm,autocancel=autocancel,father=father)
-                        print('make new order',corder['instid'],price, corder['cancelvol'] )
-                        context.orders[oid]['autoremake'][statusloc] ='finished'
-                        if 'son' in context.orders[father]:
-                            context.orders[father]['son'] += orderids
-                        else:
-                            context.orders[father]['son'] = orderids
-                            
-                        continue    
-
-        except Exception as e:
-            logger.error(f"qestratprocess autoOrders error {e}",exc_info=True )  
        
     def getPreviousTradingDay(self):
         prev_date = datetime.strptime(self.tradingday,'%Y%m%d') 
@@ -608,20 +410,20 @@ class qeStratProcess:
             
             if self.recmode and not self.posLoaded:
                 self.posLoaded = True
-                pos,instPnl = readStratPosition(self.name, context.tradingday)
+                pos,instPnl = readStratPosition_wrap(self.name, context.tradingday)
                 if pos == {} and instPnl == {}:
                     prev_date = self.getPreviousTradingDay() 
-                    context.position, context.instClosePnl = readStratPosition(self.name, prev_date.strftime('%Y%m%d'))
+                    context.position, context.instClosePnl = readStratPosition_wrap(self.name, prev_date.strftime('%Y%m%d'))
                     
                 else:
                     context.position = pos
                     context.instClosePnl = instPnl
                 simuaccount.updateStratPostion(context.position)
-                context.prodMaxMarg,context.prodTurnover = readStratStat(self.name,context.tradingday)
+                context.prodMaxMarg,context.prodTurnover = readStratStat_wrap(self.name,context.tradingday)
                 ## write back to database
-                writeStratPosition(self.name, context.tradingday,context.position,context.instClosePnl)
-                writeContractTable(self.name, context.tradingday,context.position)
-                writeStratStat(self.name,context.tradingday, context.prodMaxMarg, context.prodTurnover)
+                writeStratPosition_wrap(self.name, context.tradingday,context.position,context.instClosePnl)
+                writeContractTable_wrap(self.name, context.tradingday,context.position)
+                writeStratStat_wrap(self.name,context.tradingday, context.prodMaxMarg, context.prodTurnover)
                 #context.instsett = qeInstSett()        
                 
             context.current[tempinstid] = d['data']['current']
@@ -684,9 +486,9 @@ class qeStratProcess:
         logger.info('Strat Process crossDay')        
         if self.recmode:
             lastday = context.lastday.replace('-','')
-            writeStratPosition(self.name, lastday,context.position,context.instClosePnl)
-            writeContractTable(self.name, lastday,context.position)
-            writeStratStat(self.name,lastday, context.prodMaxMarg, context.prodTurnover)
+            writeStratPosition_wrap(self.name, lastday,context.position,context.instClosePnl)
+            writeContractTable_wrap(self.name, lastday,context.position)
+            writeStratStat_wrap(self.name,lastday, context.prodMaxMarg, context.prodTurnover)
            
     def handleOrder(self,order,context):  
         try:     
@@ -725,11 +527,11 @@ class qeStratProcess:
             context.simuTrade(trade)
             context.updateData() 
             if self.recmode:
-                writeStratPosition(self.name, context.tradingday,context.position,context.instClosePnl)
-                writeContractTable(self.name, context.tradingday,context.position)
-                writeStratStat(self.name,context.tradingday, context.prodMaxMarg, context.prodTurnover)
-                writeStratTrade(self.name,context.tradingday, trade)
-                writeContract_messages(self.name,context.tradingday, trade)
+                writeStratPosition_wrap(self.name, context.tradingday,context.position,context.instClosePnl)
+                writeContractTable_wrap(self.name, context.tradingday,context.position)
+                writeStratStat_wrap(self.name,context.tradingday, context.prodMaxMarg, context.prodTurnover)
+                writeStratTrade_wrap(self.name,context.tradingday, trade)
+                writeContract_messages_wrap(self.name,context.tradingday, trade)
         except Exception as e:
             logger.error(f"handletrade error {e}",exc_info=True )
     
